AuthorizationMethod enum

Inheritance
Available extensions

Values

swaggerGeneratedUnknown → const AuthorizationMethod
const AuthorizationMethod(null)
invalid → const AuthorizationMethod
const AuthorizationMethod('invalid')
public → const AuthorizationMethod
const AuthorizationMethod('public')
authorizationHeader → const AuthorizationMethod
const AuthorizationMethod('authorization_header')
signedUrl → const AuthorizationMethod
const AuthorizationMethod('signed_url')
const AuthorizationMethod('shareable_link')
livekitToken → const AuthorizationMethod
const AuthorizationMethod('livekit_token')
livekitTokenWebsite → const AuthorizationMethod
const AuthorizationMethod('livekit_token_website')

Properties

hashCode int
The hash code for this object.
no setterinherited
index int
A numeric identifier for the enumerated value.
no setterinherited
name String

Available on Enum, provided by the EnumName extension

The name of the enum value.
no setter
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
value String?
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited

Constants

values → const List<AuthorizationMethod>
A constant List of the values in this enum, in order of their declaration.