GetConversationResponseModelStatus enum
Values
- swaggerGeneratedUnknown → const GetConversationResponseModelStatus
-
const GetConversationResponseModelStatus(null) - initiated → const GetConversationResponseModelStatus
-
const GetConversationResponseModelStatus('initiated') - inProgress → const GetConversationResponseModelStatus
-
const GetConversationResponseModelStatus('in-progress') - processing → const GetConversationResponseModelStatus
-
const GetConversationResponseModelStatus('processing') - done → const GetConversationResponseModelStatus
-
const GetConversationResponseModelStatus('done') - failed → const GetConversationResponseModelStatus
-
const GetConversationResponseModelStatus('failed')
Properties
- hashCode → int
-
The hash code for this object.
no setterinherited
- index → int
-
A numeric identifier for the enumerated value.
no setterinherited
- name → String
-
Available on Enum, provided by the EnumName extension
The name of the enum value.no setter - runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- value → String?
-
final
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited
Constants
-
values
→ const List<
GetConversationResponseModelStatus> - A constant List of the values in this enum, in order of their declaration.