LibraryVoiceResponseModelCategory enum
Values
- swaggerGeneratedUnknown → const LibraryVoiceResponseModelCategory
-
const LibraryVoiceResponseModelCategory(null) - generated → const LibraryVoiceResponseModelCategory
-
const LibraryVoiceResponseModelCategory('generated') - cloned → const LibraryVoiceResponseModelCategory
-
const LibraryVoiceResponseModelCategory('cloned') - premade → const LibraryVoiceResponseModelCategory
-
const LibraryVoiceResponseModelCategory('premade') - professional → const LibraryVoiceResponseModelCategory
-
const LibraryVoiceResponseModelCategory('professional') - famous → const LibraryVoiceResponseModelCategory
-
const LibraryVoiceResponseModelCategory('famous') - highQuality → const LibraryVoiceResponseModelCategory
-
const LibraryVoiceResponseModelCategory('high_quality')
Properties
- hashCode → int
-
The hash code for this object.
no setterinherited
- index → int
-
A numeric identifier for the enumerated value.
no setterinherited
- name → String
-
Available on Enum, provided by the EnumName extension
The name of the enum value.no setter - runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- value → String?
-
final
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited
Constants
-
values
→ const List<
LibraryVoiceResponseModelCategory> - A constant List of the values in this enum, in order of their declaration.