TTSOptimizeStreamingLatency enum
Values
- swaggerGeneratedUnknown → const TTSOptimizeStreamingLatency
-
const TTSOptimizeStreamingLatency(null) - value_0 → const TTSOptimizeStreamingLatency
-
const TTSOptimizeStreamingLatency(0) - value_1 → const TTSOptimizeStreamingLatency
-
const TTSOptimizeStreamingLatency(1) - value_2 → const TTSOptimizeStreamingLatency
-
const TTSOptimizeStreamingLatency(2) - value_3 → const TTSOptimizeStreamingLatency
-
const TTSOptimizeStreamingLatency(3) - value_4 → const TTSOptimizeStreamingLatency
-
const TTSOptimizeStreamingLatency(4)
Properties
- hashCode → int
-
The hash code for this object.
no setterinherited
- index → int
-
A numeric identifier for the enumerated value.
no setterinherited
- name → String
-
Available on Enum, provided by the EnumName extension
The name of the enum value.no setter - runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- value → int?
-
final
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited
Constants
-
values
→ const List<
TTSOptimizeStreamingLatency> - A constant List of the values in this enum, in order of their declaration.