AddPronunciationDictionaryResponseModel class

Available extensions
Annotations
  • @JsonSerializable.new(explicitToJson: true)

Constructors

AddPronunciationDictionaryResponseModel({required String id, required String name, required String createdBy, required int creationTimeUnix, required String versionId, required int versionRulesNum, dynamic description, required dynamic permissionOnResource})
const
AddPronunciationDictionaryResponseModel.fromJson(Map<String, dynamic> json)
factory

Properties

createdBy String
final
creationTimeUnix int
final
description → dynamic
final
hashCode int
The hash code for this object.
no setteroverride
id String
final
name String
final
permissionOnResource → dynamic
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
versionId String
final
versionRulesNum int
final

Methods

copyWith({String? id, String? name, String? createdBy, int? creationTimeUnix, String? versionId, int? versionRulesNum, dynamic description, dynamic permissionOnResource}) AddPronunciationDictionaryResponseModel

Available on AddPronunciationDictionaryResponseModel, provided by the $AddPronunciationDictionaryResponseModelExtension extension

copyWithWrapped({Wrapped<String>? id, Wrapped<String>? name, Wrapped<String>? createdBy, Wrapped<int>? creationTimeUnix, Wrapped<String>? versionId, Wrapped<int>? versionRulesNum, Wrapped? description, Wrapped? permissionOnResource}) AddPronunciationDictionaryResponseModel

Available on AddPronunciationDictionaryResponseModel, provided by the $AddPronunciationDictionaryResponseModelExtension extension

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() Map<String, dynamic>
toString() String
A string representation of this object.
override

Operators

operator ==(Object other) bool
The equality operator.
override

Constants

fromJsonFactory → const AddPronunciationDictionaryResponseModel Function(Map<String, dynamic> json)
toJsonFactory → const Map<String, dynamic> Function(AddPronunciationDictionaryResponseModel instance)