AgentTransfer class

Available extensions
Annotations
  • @JsonSerializable.new(explicitToJson: true)

Constructors

AgentTransfer({required String agentId, required String condition})
const
AgentTransfer.fromJson(Map<String, dynamic> json)
factory

Properties

agentId String
final
condition String
final
hashCode int
The hash code for this object.
no setteroverride
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

copyWith({String? agentId, String? condition}) AgentTransfer

Available on AgentTransfer, provided by the $AgentTransferExtension extension

copyWithWrapped({Wrapped<String>? agentId, Wrapped<String>? condition}) AgentTransfer

Available on AgentTransfer, provided by the $AgentTransferExtension extension

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() Map<String, dynamic>
toString() String
A string representation of this object.
override

Operators

operator ==(Object other) bool
The equality operator.
override

Constants

fromJsonFactory → const AgentTransfer Function(Map<String, dynamic> json)
toJsonFactory → const Map<String, dynamic> Function(AgentTransfer instance)