AgentWorkspaceOverridesInput class

Available extensions
Annotations
  • @JsonSerializable.new(explicitToJson: true)

Constructors

AgentWorkspaceOverridesInput({dynamic conversationInitiationClientDataWebhook, ConvAIWebhooks? webhooks})
const
AgentWorkspaceOverridesInput.fromJson(Map<String, dynamic> json)
factory

Properties

conversationInitiationClientDataWebhook → dynamic
final
hashCode int
The hash code for this object.
no setteroverride
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
webhooks ConvAIWebhooks?
final

Methods

copyWith({dynamic conversationInitiationClientDataWebhook, ConvAIWebhooks? webhooks}) AgentWorkspaceOverridesInput

Available on AgentWorkspaceOverridesInput, provided by the $AgentWorkspaceOverridesInputExtension extension

copyWithWrapped({Wrapped? conversationInitiationClientDataWebhook, Wrapped<ConvAIWebhooks?>? webhooks}) AgentWorkspaceOverridesInput

Available on AgentWorkspaceOverridesInput, provided by the $AgentWorkspaceOverridesInputExtension extension

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() Map<String, dynamic>
toString() String
A string representation of this object.
override

Operators

operator ==(Object other) bool
The equality operator.
override

Constants

fromJsonFactory → const AgentWorkspaceOverridesInput Function(Map<String, dynamic> json)
toJsonFactory → const Map<String, dynamic> Function(AgentWorkspaceOverridesInput instance)