AgentWorkspaceOverridesOutput class

Available extensions
Annotations
  • @JsonSerializable.new(explicitToJson: true)

Constructors

AgentWorkspaceOverridesOutput({dynamic conversationInitiationClientDataWebhook, ConvAIWebhooks? webhooks})
const
AgentWorkspaceOverridesOutput.fromJson(Map<String, dynamic> json)
factory

Properties

conversationInitiationClientDataWebhook → dynamic
final
hashCode int
The hash code for this object.
no setteroverride
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
webhooks ConvAIWebhooks?
final

Methods

copyWith({dynamic conversationInitiationClientDataWebhook, ConvAIWebhooks? webhooks}) AgentWorkspaceOverridesOutput

Available on AgentWorkspaceOverridesOutput, provided by the $AgentWorkspaceOverridesOutputExtension extension

copyWithWrapped({Wrapped? conversationInitiationClientDataWebhook, Wrapped<ConvAIWebhooks?>? webhooks}) AgentWorkspaceOverridesOutput

Available on AgentWorkspaceOverridesOutput, provided by the $AgentWorkspaceOverridesOutputExtension extension

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() Map<String, dynamic>
toString() String
A string representation of this object.
override

Operators

operator ==(Object other) bool
The equality operator.
override

Constants

fromJsonFactory → const AgentWorkspaceOverridesOutput Function(Map<String, dynamic> json)
toJsonFactory → const Map<String, dynamic> Function(AgentWorkspaceOverridesOutput instance)