BatchCallResponse class

Available extensions
Annotations
  • @JsonSerializable.new(explicitToJson: true)

Constructors

BatchCallResponse({required String id, required String phoneNumberId, TelephonyProvider? phoneProvider, required String name, required String agentId, required int createdAtUnix, required int scheduledTimeUnix, required int totalCallsDispatched, required int totalCallsScheduled, required int lastUpdatedAtUnix, required BatchCallStatus status, required String agentName})
const
BatchCallResponse.fromJson(Map<String, dynamic> json)
factory

Properties

agentId String
final
agentName String
final
createdAtUnix int
final
hashCode int
The hash code for this object.
no setteroverride
id String
final
lastUpdatedAtUnix int
final
name String
final
phoneNumberId String
final
phoneProvider TelephonyProvider?
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
scheduledTimeUnix int
final
status BatchCallStatus
final
totalCallsDispatched int
final
totalCallsScheduled int
final

Methods

copyWith({String? id, String? phoneNumberId, TelephonyProvider? phoneProvider, String? name, String? agentId, int? createdAtUnix, int? scheduledTimeUnix, int? totalCallsDispatched, int? totalCallsScheduled, int? lastUpdatedAtUnix, BatchCallStatus? status, String? agentName}) BatchCallResponse

Available on BatchCallResponse, provided by the $BatchCallResponseExtension extension

copyWithWrapped({Wrapped<String>? id, Wrapped<String>? phoneNumberId, Wrapped<TelephonyProvider?>? phoneProvider, Wrapped<String>? name, Wrapped<String>? agentId, Wrapped<int>? createdAtUnix, Wrapped<int>? scheduledTimeUnix, Wrapped<int>? totalCallsDispatched, Wrapped<int>? totalCallsScheduled, Wrapped<int>? lastUpdatedAtUnix, Wrapped<BatchCallStatus>? status, Wrapped<String>? agentName}) BatchCallResponse

Available on BatchCallResponse, provided by the $BatchCallResponseExtension extension

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() Map<String, dynamic>
toString() String
A string representation of this object.
override

Operators

operator ==(Object other) bool
The equality operator.
override

Constants

fromJsonFactory → const BatchCallResponse Function(Map<String, dynamic> json)
toJsonFactory → const Map<String, dynamic> Function(BatchCallResponse instance)