BodyAddALanguageToTheResourceV1DubbingResourceDubbingIdLanguagePost class
- Available extensions
- Annotations
-
- @JsonSerializable.new(explicitToJson: true)
Constructors
- BodyAddALanguageToTheResourceV1DubbingResourceDubbingIdLanguagePost({required dynamic language})
-
const
-
BodyAddALanguageToTheResourceV1DubbingResourceDubbingIdLanguagePost.fromJson(Map<
String, dynamic> json) -
factory
Properties
- hashCode → int
-
The hash code for this object.
no setteroverride
- language → dynamic
-
final
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
copyWith(
{dynamic language}) → BodyAddALanguageToTheResourceV1DubbingResourceDubbingIdLanguagePost -
Available on BodyAddALanguageToTheResourceV1DubbingResourceDubbingIdLanguagePost, provided by the $BodyAddALanguageToTheResourceV1DubbingResourceDubbingIdLanguagePostExtension extension
-
copyWithWrapped(
{Wrapped? language}) → BodyAddALanguageToTheResourceV1DubbingResourceDubbingIdLanguagePost -
Available on BodyAddALanguageToTheResourceV1DubbingResourceDubbingIdLanguagePost, provided by the $BodyAddALanguageToTheResourceV1DubbingResourceDubbingIdLanguagePostExtension extension
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toJson(
) → Map< String, dynamic> -
toString(
) → String -
A string representation of this object.
override
Operators
-
operator ==(
Object other) → bool -
The equality operator.
override
Constants
-
fromJsonFactory
→ const BodyAddALanguageToTheResourceV1DubbingResourceDubbingIdLanguagePost Function(Map<
String, dynamic> json) -
toJsonFactory
→ const Map<
String, dynamic> Function(BodyAddALanguageToTheResourceV1DubbingResourceDubbingIdLanguagePost instance)