ConvAIDynamicVariable class

Available extensions
Annotations
  • @JsonSerializable.new(explicitToJson: true)

Constructors

ConvAIDynamicVariable({required String variableName})
const
ConvAIDynamicVariable.fromJson(Map<String, dynamic> json)
factory

Properties

hashCode int
The hash code for this object.
no setteroverride
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
variableName String
final

Methods

copyWith({String? variableName}) ConvAIDynamicVariable

Available on ConvAIDynamicVariable, provided by the $ConvAIDynamicVariableExtension extension

copyWithWrapped({Wrapped<String>? variableName}) ConvAIDynamicVariable

Available on ConvAIDynamicVariable, provided by the $ConvAIDynamicVariableExtension extension

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() Map<String, dynamic>
toString() String
A string representation of this object.
override

Operators

operator ==(Object other) bool
The equality operator.
override

Constants

fromJsonFactory → const ConvAIDynamicVariable Function(Map<String, dynamic> json)
toJsonFactory → const Map<String, dynamic> Function(ConvAIDynamicVariable instance)