ConvAIWorkspaceStoredSecretConfig class

Available extensions
Annotations
  • @JsonSerializable.new(explicitToJson: true)

Constructors

ConvAIWorkspaceStoredSecretConfig({required String type, required String secretId, required String name, required ConvAIStoredSecretDependencies usedBy})
const
ConvAIWorkspaceStoredSecretConfig.fromJson(Map<String, dynamic> json)
factory

Properties

hashCode int
The hash code for this object.
no setteroverride
name String
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
secretId String
final
type String
final
usedBy ConvAIStoredSecretDependencies
final

Methods

copyWith({String? type, String? secretId, String? name, ConvAIStoredSecretDependencies? usedBy}) ConvAIWorkspaceStoredSecretConfig

Available on ConvAIWorkspaceStoredSecretConfig, provided by the $ConvAIWorkspaceStoredSecretConfigExtension extension

copyWithWrapped({Wrapped<String>? type, Wrapped<String>? secretId, Wrapped<String>? name, Wrapped<ConvAIStoredSecretDependencies>? usedBy}) ConvAIWorkspaceStoredSecretConfig

Available on ConvAIWorkspaceStoredSecretConfig, provided by the $ConvAIWorkspaceStoredSecretConfigExtension extension

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() Map<String, dynamic>
toString() String
A string representation of this object.
override

Operators

operator ==(Object other) bool
The equality operator.
override

Constants

fromJsonFactory → const ConvAIWorkspaceStoredSecretConfig Function(Map<String, dynamic> json)
toJsonFactory → const Map<String, dynamic> Function(ConvAIWorkspaceStoredSecretConfig instance)