ConversationHistoryRagUsageCommonModel class
- Available extensions
- Annotations
-
- @JsonSerializable.new(explicitToJson: true)
Constructors
- ConversationHistoryRagUsageCommonModel({required int usageCount, required String embeddingModel})
-
const
-
ConversationHistoryRagUsageCommonModel.fromJson(Map<
String, dynamic> json) -
factory
Properties
- embeddingModel → String
-
final
- hashCode → int
-
The hash code for this object.
no setteroverride
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- usageCount → int
-
final
Methods
-
copyWith(
{int? usageCount, String? embeddingModel}) → ConversationHistoryRagUsageCommonModel -
Available on ConversationHistoryRagUsageCommonModel, provided by the $ConversationHistoryRagUsageCommonModelExtension extension
-
copyWithWrapped(
{Wrapped< int> ? usageCount, Wrapped<String> ? embeddingModel}) → ConversationHistoryRagUsageCommonModel -
Available on ConversationHistoryRagUsageCommonModel, provided by the $ConversationHistoryRagUsageCommonModelExtension extension
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toJson(
) → Map< String, dynamic> -
toString(
) → String -
A string representation of this object.
override
Operators
-
operator ==(
Object other) → bool -
The equality operator.
override
Constants
-
fromJsonFactory
→ const ConversationHistoryRagUsageCommonModel Function(Map<
String, dynamic> json) -
toJsonFactory
→ const Map<
String, dynamic> Function(ConversationHistoryRagUsageCommonModel instance)