ConversationHistorySIPTrunkingPhoneCallModel class

Available extensions
Annotations
  • @JsonSerializable.new(explicitToJson: true)

Constructors

ConversationHistorySIPTrunkingPhoneCallModel({required ConversationHistorySIPTrunkingPhoneCallModelDirection direction, required String phoneNumberId, required String agentNumber, required String externalNumber, required String type, required String callSid})
const
ConversationHistorySIPTrunkingPhoneCallModel.fromJson(Map<String, dynamic> json)
factory

Properties

agentNumber String
final
callSid String
final
direction ConversationHistorySIPTrunkingPhoneCallModelDirection
final
externalNumber String
final
hashCode int
The hash code for this object.
no setteroverride
phoneNumberId String
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
type String
final

Methods

copyWith({ConversationHistorySIPTrunkingPhoneCallModelDirection? direction, String? phoneNumberId, String? agentNumber, String? externalNumber, String? type, String? callSid}) ConversationHistorySIPTrunkingPhoneCallModel

Available on ConversationHistorySIPTrunkingPhoneCallModel, provided by the $ConversationHistorySIPTrunkingPhoneCallModelExtension extension

copyWithWrapped({Wrapped<ConversationHistorySIPTrunkingPhoneCallModelDirection>? direction, Wrapped<String>? phoneNumberId, Wrapped<String>? agentNumber, Wrapped<String>? externalNumber, Wrapped<String>? type, Wrapped<String>? callSid}) ConversationHistorySIPTrunkingPhoneCallModel

Available on ConversationHistorySIPTrunkingPhoneCallModel, provided by the $ConversationHistorySIPTrunkingPhoneCallModelExtension extension

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() Map<String, dynamic>
toString() String
A string representation of this object.
override

Operators

operator ==(Object other) bool
The equality operator.
override

Constants

fromJsonFactory → const ConversationHistorySIPTrunkingPhoneCallModel Function(Map<String, dynamic> json)
toJsonFactory → const Map<String, dynamic> Function(ConversationHistorySIPTrunkingPhoneCallModel instance)