ConversationSummaryResponseModel class

Available extensions
Annotations
  • @JsonSerializable.new(explicitToJson: true)

Constructors

ConversationSummaryResponseModel({required String agentId, dynamic agentName, required String conversationId, required int startTimeUnixSecs, required int callDurationSecs, required int messageCount, required ConversationSummaryResponseModelStatus status, required EvaluationSuccessResult callSuccessful})
const
ConversationSummaryResponseModel.fromJson(Map<String, dynamic> json)
factory

Properties

agentId String
final
agentName → dynamic
final
callDurationSecs int
final
callSuccessful EvaluationSuccessResult
final
conversationId String
final
hashCode int
The hash code for this object.
no setteroverride
messageCount int
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
startTimeUnixSecs int
final
status ConversationSummaryResponseModelStatus
final

Methods

copyWith({String? agentId, dynamic agentName, String? conversationId, int? startTimeUnixSecs, int? callDurationSecs, int? messageCount, ConversationSummaryResponseModelStatus? status, EvaluationSuccessResult? callSuccessful}) ConversationSummaryResponseModel

Available on ConversationSummaryResponseModel, provided by the $ConversationSummaryResponseModelExtension extension

copyWithWrapped({Wrapped<String>? agentId, Wrapped? agentName, Wrapped<String>? conversationId, Wrapped<int>? startTimeUnixSecs, Wrapped<int>? callDurationSecs, Wrapped<int>? messageCount, Wrapped<ConversationSummaryResponseModelStatus>? status, Wrapped<EvaluationSuccessResult>? callSuccessful}) ConversationSummaryResponseModel

Available on ConversationSummaryResponseModel, provided by the $ConversationSummaryResponseModelExtension extension

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() Map<String, dynamic>
toString() String
A string representation of this object.
override

Operators

operator ==(Object other) bool
The equality operator.
override

Constants

fromJsonFactory → const ConversationSummaryResponseModel Function(Map<String, dynamic> json)
toJsonFactory → const Map<String, dynamic> Function(ConversationSummaryResponseModel instance)