CreateTwilioPhoneNumberRequest class

Available extensions
Annotations
  • @JsonSerializable.new(explicitToJson: true)

Constructors

CreateTwilioPhoneNumberRequest({required String phoneNumber, required String label, String? provider, required String sid, required String token})
const
CreateTwilioPhoneNumberRequest.fromJson(Map<String, dynamic> json)
factory

Properties

hashCode int
The hash code for this object.
no setteroverride
label String
final
phoneNumber String
final
provider String?
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
sid String
final
token String
final

Methods

copyWith({String? phoneNumber, String? label, String? provider, String? sid, String? token}) CreateTwilioPhoneNumberRequest

Available on CreateTwilioPhoneNumberRequest, provided by the $CreateTwilioPhoneNumberRequestExtension extension

copyWithWrapped({Wrapped<String>? phoneNumber, Wrapped<String>? label, Wrapped<String?>? provider, Wrapped<String>? sid, Wrapped<String>? token}) CreateTwilioPhoneNumberRequest

Available on CreateTwilioPhoneNumberRequest, provided by the $CreateTwilioPhoneNumberRequestExtension extension

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() Map<String, dynamic>
toString() String
A string representation of this object.
override

Operators

operator ==(Object other) bool
The equality operator.
override

Constants

fromJsonFactory → const CreateTwilioPhoneNumberRequest Function(Map<String, dynamic> json)
toJsonFactory → const Map<String, dynamic> Function(CreateTwilioPhoneNumberRequest instance)