DashboardCriteriaChartModel class
- Available extensions
- Annotations
-
- @JsonSerializable.new(explicitToJson: true)
Constructors
- DashboardCriteriaChartModel({required String name, String? type, required String criteriaId})
-
const
-
DashboardCriteriaChartModel.fromJson(Map<
String, dynamic> json) -
factory
Properties
- criteriaId → String
-
final
- hashCode → int
-
The hash code for this object.
no setteroverride
- name → String
-
final
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- type → String?
-
final
Methods
-
copyWith(
{String? name, String? type, String? criteriaId}) → DashboardCriteriaChartModel -
Available on DashboardCriteriaChartModel, provided by the $DashboardCriteriaChartModelExtension extension
-
copyWithWrapped(
{Wrapped< String> ? name, Wrapped<String?> ? type, Wrapped<String> ? criteriaId}) → DashboardCriteriaChartModel -
Available on DashboardCriteriaChartModel, provided by the $DashboardCriteriaChartModelExtension extension
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toJson(
) → Map< String, dynamic> -
toString(
) → String -
A string representation of this object.
override
Operators
-
operator ==(
Object other) → bool -
The equality operator.
override
Constants
-
fromJsonFactory
→ const DashboardCriteriaChartModel Function(Map<
String, dynamic> json) -
toJsonFactory
→ const Map<
String, dynamic> Function(DashboardCriteriaChartModel instance)