DubbingMediaReference class

Available extensions
Annotations
  • @JsonSerializable.new(explicitToJson: true)

Constructors

DubbingMediaReference({required String src, required String contentType, required String bucketName, required String randomPathSlug, required double durationSecs, required bool isAudio, required String url})
const
DubbingMediaReference.fromJson(Map<String, dynamic> json)
factory

Properties

bucketName String
final
contentType String
final
durationSecs double
final
hashCode int
The hash code for this object.
no setteroverride
isAudio bool
final
randomPathSlug String
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
src String
final
url String
final

Methods

copyWith({String? src, String? contentType, String? bucketName, String? randomPathSlug, double? durationSecs, bool? isAudio, String? url}) DubbingMediaReference

Available on DubbingMediaReference, provided by the $DubbingMediaReferenceExtension extension

copyWithWrapped({Wrapped<String>? src, Wrapped<String>? contentType, Wrapped<String>? bucketName, Wrapped<String>? randomPathSlug, Wrapped<double>? durationSecs, Wrapped<bool>? isAudio, Wrapped<String>? url}) DubbingMediaReference

Available on DubbingMediaReference, provided by the $DubbingMediaReferenceExtension extension

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() Map<String, dynamic>
toString() String
A string representation of this object.
override

Operators

operator ==(Object other) bool
The equality operator.
override

Constants

fromJsonFactory → const DubbingMediaReference Function(Map<String, dynamic> json)
toJsonFactory → const Map<String, dynamic> Function(DubbingMediaReference instance)