GetPhoneNumberTwilioResponseModel class

Available extensions
Annotations
  • @JsonSerializable.new(explicitToJson: true)

Constructors

GetPhoneNumberTwilioResponseModel({required String phoneNumber, required String label, required String phoneNumberId, dynamic assignedAgent, String? provider})
const
GetPhoneNumberTwilioResponseModel.fromJson(Map<String, dynamic> json)
factory

Properties

assignedAgent → dynamic
final
hashCode int
The hash code for this object.
no setteroverride
label String
final
phoneNumber String
final
phoneNumberId String
final
provider String?
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

copyWith({String? phoneNumber, String? label, String? phoneNumberId, dynamic assignedAgent, String? provider}) GetPhoneNumberTwilioResponseModel

Available on GetPhoneNumberTwilioResponseModel, provided by the $GetPhoneNumberTwilioResponseModelExtension extension

copyWithWrapped({Wrapped<String>? phoneNumber, Wrapped<String>? label, Wrapped<String>? phoneNumberId, Wrapped? assignedAgent, Wrapped<String?>? provider}) GetPhoneNumberTwilioResponseModel

Available on GetPhoneNumberTwilioResponseModel, provided by the $GetPhoneNumberTwilioResponseModelExtension extension

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() Map<String, dynamic>
toString() String
A string representation of this object.
override

Operators

operator ==(Object other) bool
The equality operator.
override

Constants

fromJsonFactory → const GetPhoneNumberTwilioResponseModel Function(Map<String, dynamic> json)
toJsonFactory → const Map<String, dynamic> Function(GetPhoneNumberTwilioResponseModel instance)