GetPronunciationDictionaryMetadataResponseModel class

Available extensions
Annotations
  • @JsonSerializable.new(explicitToJson: true)

Constructors

GetPronunciationDictionaryMetadataResponseModel({required String id, required String latestVersionId, required int latestVersionRulesNum, required String name, required dynamic permissionOnResource, required String createdBy, required int creationTimeUnix, required dynamic archivedTimeUnix, dynamic description})
const
GetPronunciationDictionaryMetadataResponseModel.fromJson(Map<String, dynamic> json)
factory

Properties

archivedTimeUnix → dynamic
final
createdBy String
final
creationTimeUnix int
final
description → dynamic
final
hashCode int
The hash code for this object.
no setteroverride
id String
final
latestVersionId String
final
latestVersionRulesNum int
final
name String
final
permissionOnResource → dynamic
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

copyWith({String? id, String? latestVersionId, int? latestVersionRulesNum, String? name, dynamic permissionOnResource, String? createdBy, int? creationTimeUnix, dynamic archivedTimeUnix, dynamic description}) GetPronunciationDictionaryMetadataResponseModel

Available on GetPronunciationDictionaryMetadataResponseModel, provided by the $GetPronunciationDictionaryMetadataResponseModelExtension extension

copyWithWrapped({Wrapped<String>? id, Wrapped<String>? latestVersionId, Wrapped<int>? latestVersionRulesNum, Wrapped<String>? name, Wrapped? permissionOnResource, Wrapped<String>? createdBy, Wrapped<int>? creationTimeUnix, Wrapped? archivedTimeUnix, Wrapped? description}) GetPronunciationDictionaryMetadataResponseModel

Available on GetPronunciationDictionaryMetadataResponseModel, provided by the $GetPronunciationDictionaryMetadataResponseModelExtension extension

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() Map<String, dynamic>
toString() String
A string representation of this object.
override

Operators

operator ==(Object other) bool
The equality operator.
override