GetVoicesResponseModel class

Available extensions
Annotations
  • @JsonSerializable.new(explicitToJson: true)

Constructors

GetVoicesResponseModel({required List<VoiceResponseModel> voices})
const
GetVoicesResponseModel.fromJson(Map<String, dynamic> json)
factory

Properties

hashCode int
The hash code for this object.
no setteroverride
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
voices List<VoiceResponseModel>
final

Methods

copyWith({List<VoiceResponseModel>? voices}) GetVoicesResponseModel

Available on GetVoicesResponseModel, provided by the $GetVoicesResponseModelExtension extension

copyWithWrapped({Wrapped<List<VoiceResponseModel>>? voices}) GetVoicesResponseModel

Available on GetVoicesResponseModel, provided by the $GetVoicesResponseModelExtension extension

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() Map<String, dynamic>
toString() String
A string representation of this object.
override

Operators

operator ==(Object other) bool
The equality operator.
override

Constants

fromJsonFactory → const GetVoicesResponseModel Function(Map<String, dynamic> json)
toJsonFactory → const Map<String, dynamic> Function(GetVoicesResponseModel instance)