ManualVerificationResponseModel class

Available extensions
Annotations
  • @JsonSerializable.new(explicitToJson: true)

Constructors

ManualVerificationResponseModel({required String extraText, required int requestTimeUnix, required List<ManualVerificationFileResponseModel> files})
const
ManualVerificationResponseModel.fromJson(Map<String, dynamic> json)
factory

Properties

extraText String
final
files List<ManualVerificationFileResponseModel>
final
hashCode int
The hash code for this object.
no setteroverride
requestTimeUnix int
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

copyWith({String? extraText, int? requestTimeUnix, List<ManualVerificationFileResponseModel>? files}) ManualVerificationResponseModel

Available on ManualVerificationResponseModel, provided by the $ManualVerificationResponseModelExtension extension

copyWithWrapped({Wrapped<String>? extraText, Wrapped<int>? requestTimeUnix, Wrapped<List<ManualVerificationFileResponseModel>>? files}) ManualVerificationResponseModel

Available on ManualVerificationResponseModel, provided by the $ManualVerificationResponseModelExtension extension

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() Map<String, dynamic>
toString() String
A string representation of this object.
override

Operators

operator ==(Object other) bool
The equality operator.
override

Constants

fromJsonFactory → const ManualVerificationResponseModel Function(Map<String, dynamic> json)
toJsonFactory → const Map<String, dynamic> Function(ManualVerificationResponseModel instance)