PatchConvAISettingsRequest class

Available extensions
Annotations
  • @JsonSerializable.new(explicitToJson: true)

Constructors

PatchConvAISettingsRequest({dynamic conversationInitiationClientDataWebhook, ConvAIWebhooks? webhooks, bool? canUseMcpServers, int? ragRetentionPeriodDays})
const
PatchConvAISettingsRequest.fromJson(Map<String, dynamic> json)
factory

Properties

canUseMcpServers bool?
final
conversationInitiationClientDataWebhook → dynamic
final
hashCode int
The hash code for this object.
no setteroverride
ragRetentionPeriodDays int?
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
webhooks ConvAIWebhooks?
final

Methods

copyWith({dynamic conversationInitiationClientDataWebhook, ConvAIWebhooks? webhooks, bool? canUseMcpServers, int? ragRetentionPeriodDays}) PatchConvAISettingsRequest

Available on PatchConvAISettingsRequest, provided by the $PatchConvAISettingsRequestExtension extension

copyWithWrapped({Wrapped? conversationInitiationClientDataWebhook, Wrapped<ConvAIWebhooks?>? webhooks, Wrapped<bool?>? canUseMcpServers, Wrapped<int?>? ragRetentionPeriodDays}) PatchConvAISettingsRequest

Available on PatchConvAISettingsRequest, provided by the $PatchConvAISettingsRequestExtension extension

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() Map<String, dynamic>
toString() String
A string representation of this object.
override

Operators

operator ==(Object other) bool
The equality operator.
override

Constants

fromJsonFactory → const PatchConvAISettingsRequest Function(Map<String, dynamic> json)
toJsonFactory → const Map<String, dynamic> Function(PatchConvAISettingsRequest instance)