PodcastConversationModeData class
- Available extensions
- Annotations
-
- @JsonSerializable.new(explicitToJson: true)
Constructors
- PodcastConversationModeData({required String hostVoiceId, required String guestVoiceId})
-
const
-
PodcastConversationModeData.fromJson(Map<
String, dynamic> json) -
factory
Properties
- guestVoiceId → String
-
final
- hashCode → int
-
The hash code for this object.
no setteroverride
- hostVoiceId → String
-
final
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
copyWith(
{String? hostVoiceId, String? guestVoiceId}) → PodcastConversationModeData -
Available on PodcastConversationModeData, provided by the $PodcastConversationModeDataExtension extension
-
copyWithWrapped(
{Wrapped< String> ? hostVoiceId, Wrapped<String> ? guestVoiceId}) → PodcastConversationModeData -
Available on PodcastConversationModeData, provided by the $PodcastConversationModeDataExtension extension
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toJson(
) → Map< String, dynamic> -
toString(
) → String -
A string representation of this object.
override
Operators
-
operator ==(
Object other) → bool -
The equality operator.
override
Constants
-
fromJsonFactory
→ const PodcastConversationModeData Function(Map<
String, dynamic> json) -
toJsonFactory
→ const Map<
String, dynamic> Function(PodcastConversationModeData instance)