RagRetrievalInfo class

Available extensions
Annotations
  • @JsonSerializable.new(explicitToJson: true)

Constructors

RagRetrievalInfo({required List<RagChunkMetadata> chunks, required EmbeddingModelEnum embeddingModel, required String retrievalQuery, required double ragLatencySecs})
const
RagRetrievalInfo.fromJson(Map<String, dynamic> json)
factory

Properties

chunks List<RagChunkMetadata>
final
embeddingModel EmbeddingModelEnum
final
hashCode int
The hash code for this object.
no setteroverride
ragLatencySecs double
final
retrievalQuery String
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

copyWith({List<RagChunkMetadata>? chunks, EmbeddingModelEnum? embeddingModel, String? retrievalQuery, double? ragLatencySecs}) RagRetrievalInfo

Available on RagRetrievalInfo, provided by the $RagRetrievalInfoExtension extension

copyWithWrapped({Wrapped<List<RagChunkMetadata>>? chunks, Wrapped<EmbeddingModelEnum>? embeddingModel, Wrapped<String>? retrievalQuery, Wrapped<double>? ragLatencySecs}) RagRetrievalInfo

Available on RagRetrievalInfo, provided by the $RagRetrievalInfoExtension extension

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() Map<String, dynamic>
toString() String
A string representation of this object.
override

Operators

operator ==(Object other) bool
The equality operator.
override

Constants

fromJsonFactory → const RagRetrievalInfo Function(Map<String, dynamic> json)
toJsonFactory → const Map<String, dynamic> Function(RagRetrievalInfo instance)