Render class

Available extensions
Annotations
  • @JsonSerializable.new(explicitToJson: true)

Constructors

Render({required String id, required int version, required dynamic language, required dynamic type, required dynamic mediaRef, required RenderStatus status})
const
Render.fromJson(Map<String, dynamic> json)
factory

Properties

hashCode int
The hash code for this object.
no setteroverride
id String
final
language → dynamic
final
mediaRef → dynamic
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
status RenderStatus
final
type → dynamic
final
version int
final

Methods

copyWith({String? id, int? version, dynamic language, dynamic type, dynamic mediaRef, RenderStatus? status}) Render

Available on Render, provided by the $RenderExtension extension

copyWithWrapped({Wrapped<String>? id, Wrapped<int>? version, Wrapped? language, Wrapped? type, Wrapped? mediaRef, Wrapped<RenderStatus>? status}) Render

Available on Render, provided by the $RenderExtension extension

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() Map<String, dynamic>
toString() String
A string representation of this object.
override

Operators

operator ==(Object other) bool
The equality operator.
override

Constants

fromJsonFactory → const Render Function(Map<String, dynamic> json)
toJsonFactory → const Map<String, dynamic> Function(Render instance)