ResourceAccessInfo class

Available extensions
Annotations
  • @JsonSerializable.new(explicitToJson: true)

Constructors

ResourceAccessInfo({required bool isCreator, required String creatorName, required String creatorEmail, required ResourceAccessInfoRole role})
const
ResourceAccessInfo.fromJson(Map<String, dynamic> json)
factory

Properties

creatorEmail String
final
creatorName String
final
hashCode int
The hash code for this object.
no setteroverride
isCreator bool
final
role ResourceAccessInfoRole
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

copyWith({bool? isCreator, String? creatorName, String? creatorEmail, ResourceAccessInfoRole? role}) ResourceAccessInfo

Available on ResourceAccessInfo, provided by the $ResourceAccessInfoExtension extension

copyWithWrapped({Wrapped<bool>? isCreator, Wrapped<String>? creatorName, Wrapped<String>? creatorEmail, Wrapped<ResourceAccessInfoRole>? role}) ResourceAccessInfo

Available on ResourceAccessInfo, provided by the $ResourceAccessInfoExtension extension

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() Map<String, dynamic>
toString() String
A string representation of this object.
override

Operators

operator ==(Object other) bool
The equality operator.
override

Constants

fromJsonFactory → const ResourceAccessInfo Function(Map<String, dynamic> json)
toJsonFactory → const Map<String, dynamic> Function(ResourceAccessInfo instance)