SafetyEvaluation class

Available extensions
Annotations
  • @JsonSerializable.new(explicitToJson: true)

Constructors

SafetyEvaluation({bool? isUnsafe, String? llmReason, int? safetyPromptVersion, List<SafetyRule>? matchedRuleId})
const
SafetyEvaluation.fromJson(Map<String, dynamic> json)
factory

Properties

hashCode int
The hash code for this object.
no setteroverride
isUnsafe bool?
final
llmReason String?
final
matchedRuleId List<SafetyRule>?
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
safetyPromptVersion int?
final

Methods

copyWith({bool? isUnsafe, String? llmReason, int? safetyPromptVersion, List<SafetyRule>? matchedRuleId}) SafetyEvaluation

Available on SafetyEvaluation, provided by the $SafetyEvaluationExtension extension

copyWithWrapped({Wrapped<bool?>? isUnsafe, Wrapped<String?>? llmReason, Wrapped<int?>? safetyPromptVersion, Wrapped<List<SafetyRule>?>? matchedRuleId}) SafetyEvaluation

Available on SafetyEvaluation, provided by the $SafetyEvaluationExtension extension

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() Map<String, dynamic>
toString() String
A string representation of this object.
override

Operators

operator ==(Object other) bool
The equality operator.
override

Constants

fromJsonFactory → const SafetyEvaluation Function(Map<String, dynamic> json)
toJsonFactory → const Map<String, dynamic> Function(SafetyEvaluation instance)