SkipTurnToolConfig class

Available extensions
Annotations
  • @JsonSerializable.new(explicitToJson: true)

Constructors

SkipTurnToolConfig({String? systemToolType})
const
SkipTurnToolConfig.fromJson(Map<String, dynamic> json)
factory

Properties

hashCode int
The hash code for this object.
no setteroverride
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
systemToolType String?
final

Methods

copyWith({String? systemToolType}) SkipTurnToolConfig

Available on SkipTurnToolConfig, provided by the $SkipTurnToolConfigExtension extension

copyWithWrapped({Wrapped<String?>? systemToolType}) SkipTurnToolConfig

Available on SkipTurnToolConfig, provided by the $SkipTurnToolConfigExtension extension

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() Map<String, dynamic>
toString() String
A string representation of this object.
override

Operators

operator ==(Object other) bool
The equality operator.
override

Constants

fromJsonFactory → const SkipTurnToolConfig Function(Map<String, dynamic> json)
toJsonFactory → const Map<String, dynamic> Function(SkipTurnToolConfig instance)