SpeakerTrack class

Available extensions
Annotations
  • @JsonSerializable.new(explicitToJson: true)

Constructors

SpeakerTrack({required String id, required DubbingMediaReference mediaRef, required String speakerName, required Map<String, dynamic> voices, required List<String> segments})
const
SpeakerTrack.fromJson(Map<String, dynamic> json)
factory

Properties

hashCode int
The hash code for this object.
no setteroverride
id String
final
mediaRef DubbingMediaReference
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
segments List<String>
final
speakerName String
final
voices Map<String, dynamic>
final

Methods

copyWith({String? id, DubbingMediaReference? mediaRef, String? speakerName, Map<String, dynamic>? voices, List<String>? segments}) SpeakerTrack

Available on SpeakerTrack, provided by the $SpeakerTrackExtension extension

copyWithWrapped({Wrapped<String>? id, Wrapped<DubbingMediaReference>? mediaRef, Wrapped<String>? speakerName, Wrapped<Map<String, dynamic>>? voices, Wrapped<List<String>>? segments}) SpeakerTrack

Available on SpeakerTrack, provided by the $SpeakerTrackExtension extension

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() Map<String, dynamic>
toString() String
A string representation of this object.
override

Operators

operator ==(Object other) bool
The equality operator.
override

Constants

fromJsonFactory → const SpeakerTrack Function(Map<String, dynamic> json)
toJsonFactory → const Map<String, dynamic> Function(SpeakerTrack instance)