SpeechToTextWordResponseModel class

Available extensions
Annotations
  • @JsonSerializable.new(explicitToJson: true)

Constructors

SpeechToTextWordResponseModel({required String text, dynamic start, dynamic end, required SpeechToTextWordResponseModelType type, dynamic speakerId, required double logprob, dynamic characters})
const
SpeechToTextWordResponseModel.fromJson(Map<String, dynamic> json)
factory

Properties

characters → dynamic
final
end → dynamic
final
hashCode int
The hash code for this object.
no setteroverride
logprob double
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
speakerId → dynamic
final
start → dynamic
final
text String
final
type SpeechToTextWordResponseModelType
final

Methods

copyWith({String? text, dynamic start, dynamic end, SpeechToTextWordResponseModelType? type, dynamic speakerId, double? logprob, dynamic characters}) SpeechToTextWordResponseModel

Available on SpeechToTextWordResponseModel, provided by the $SpeechToTextWordResponseModelExtension extension

copyWithWrapped({Wrapped<String>? text, Wrapped? start, Wrapped? end, Wrapped<SpeechToTextWordResponseModelType>? type, Wrapped? speakerId, Wrapped<double>? logprob, Wrapped? characters}) SpeechToTextWordResponseModel

Available on SpeechToTextWordResponseModel, provided by the $SpeechToTextWordResponseModelExtension extension

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() Map<String, dynamic>
toString() String
A string representation of this object.
override

Operators

operator ==(Object other) bool
The equality operator.
override

Constants

fromJsonFactory → const SpeechToTextWordResponseModel Function(Map<String, dynamic> json)
toJsonFactory → const Map<String, dynamic> Function(SpeechToTextWordResponseModel instance)