ToolMockConfig class

Available extensions
Annotations
  • @JsonSerializable.new(explicitToJson: true)

Constructors

ToolMockConfig({String? defaultReturnValue, bool? defaultIsError})
const
ToolMockConfig.fromJson(Map<String, dynamic> json)
factory

Properties

defaultIsError bool?
final
defaultReturnValue String?
final
hashCode int
The hash code for this object.
no setteroverride
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

copyWith({String? defaultReturnValue, bool? defaultIsError}) ToolMockConfig

Available on ToolMockConfig, provided by the $ToolMockConfigExtension extension

copyWithWrapped({Wrapped<String?>? defaultReturnValue, Wrapped<bool?>? defaultIsError}) ToolMockConfig

Available on ToolMockConfig, provided by the $ToolMockConfigExtension extension

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() Map<String, dynamic>
toString() String
A string representation of this object.
override

Operators

operator ==(Object other) bool
The equality operator.
override

Constants

fromJsonFactory → const ToolMockConfig Function(Map<String, dynamic> json)
toJsonFactory → const Map<String, dynamic> Function(ToolMockConfig instance)