TxtExportOptions class

Available extensions
Annotations
  • @JsonSerializable.new(explicitToJson: true)

Constructors

TxtExportOptions({dynamic maxCharactersPerLine, bool? includeSpeakers, bool? includeTimestamps, required String format, dynamic segmentOnSilenceLongerThanS, dynamic maxSegmentDurationS, dynamic maxSegmentChars})
const
TxtExportOptions.fromJson(Map<String, dynamic> json)
factory

Properties

format String
final
hashCode int
The hash code for this object.
no setteroverride
includeSpeakers bool?
final
includeTimestamps bool?
final
maxCharactersPerLine → dynamic
final
maxSegmentChars → dynamic
final
maxSegmentDurationS → dynamic
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
segmentOnSilenceLongerThanS → dynamic
final

Methods

copyWith({dynamic maxCharactersPerLine, bool? includeSpeakers, bool? includeTimestamps, String? format, dynamic segmentOnSilenceLongerThanS, dynamic maxSegmentDurationS, dynamic maxSegmentChars}) TxtExportOptions

Available on TxtExportOptions, provided by the $TxtExportOptionsExtension extension

copyWithWrapped({Wrapped? maxCharactersPerLine, Wrapped<bool?>? includeSpeakers, Wrapped<bool?>? includeTimestamps, Wrapped<String>? format, Wrapped? segmentOnSilenceLongerThanS, Wrapped? maxSegmentDurationS, Wrapped? maxSegmentChars}) TxtExportOptions

Available on TxtExportOptions, provided by the $TxtExportOptionsExtension extension

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() Map<String, dynamic>
toString() String
A string representation of this object.
override

Operators

operator ==(Object other) bool
The equality operator.
override

Constants

fromJsonFactory → const TxtExportOptions Function(Map<String, dynamic> json)
toJsonFactory → const Map<String, dynamic> Function(TxtExportOptions instance)