UserFeedback class

Available extensions
Annotations
  • @JsonSerializable.new(explicitToJson: true)

Constructors

UserFeedback({required UserFeedbackScore score, required int timeInCallSecs})
const
UserFeedback.fromJson(Map<String, dynamic> json)
factory

Properties

hashCode int
The hash code for this object.
no setteroverride
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
score UserFeedbackScore
final
timeInCallSecs int
final

Methods

copyWith({UserFeedbackScore? score, int? timeInCallSecs}) UserFeedback

Available on UserFeedback, provided by the $UserFeedbackExtension extension

copyWithWrapped({Wrapped<UserFeedbackScore>? score, Wrapped<int>? timeInCallSecs}) UserFeedback

Available on UserFeedback, provided by the $UserFeedbackExtension extension

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() Map<String, dynamic>
toString() String
A string representation of this object.
override

Operators

operator ==(Object other) bool
The equality operator.
override

Constants

fromJsonFactory → const UserFeedback Function(Map<String, dynamic> json)
toJsonFactory → const Map<String, dynamic> Function(UserFeedback instance)