VoicePreviewsResponseModel class

Available extensions
Annotations
  • @JsonSerializable.new(explicitToJson: true)

Constructors

VoicePreviewsResponseModel({required List<VoicePreviewResponseModel> previews, required String text})
const
VoicePreviewsResponseModel.fromJson(Map<String, dynamic> json)
factory

Properties

hashCode int
The hash code for this object.
no setteroverride
previews List<VoicePreviewResponseModel>
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
text String
final

Methods

copyWith({List<VoicePreviewResponseModel>? previews, String? text}) VoicePreviewsResponseModel

Available on VoicePreviewsResponseModel, provided by the $VoicePreviewsResponseModelExtension extension

copyWithWrapped({Wrapped<List<VoicePreviewResponseModel>>? previews, Wrapped<String>? text}) VoicePreviewsResponseModel

Available on VoicePreviewsResponseModel, provided by the $VoicePreviewsResponseModelExtension extension

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() Map<String, dynamic>
toString() String
A string representation of this object.
override

Operators

operator ==(Object other) bool
The equality operator.
override

Constants

fromJsonFactory → const VoicePreviewsResponseModel Function(Map<String, dynamic> json)
toJsonFactory → const Map<String, dynamic> Function(VoicePreviewsResponseModel instance)