WidgetLanguagePreset class

Available extensions
Annotations
  • @JsonSerializable.new(explicitToJson: true)

Constructors

WidgetLanguagePreset({dynamic textContents})
const
WidgetLanguagePreset.fromJson(Map<String, dynamic> json)
factory

Properties

hashCode int
The hash code for this object.
no setteroverride
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
textContents → dynamic
final

Methods

copyWith({dynamic textContents}) WidgetLanguagePreset

Available on WidgetLanguagePreset, provided by the $WidgetLanguagePresetExtension extension

copyWithWrapped({Wrapped? textContents}) WidgetLanguagePreset

Available on WidgetLanguagePreset, provided by the $WidgetLanguagePresetExtension extension

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() Map<String, dynamic>
toString() String
A string representation of this object.
override

Operators

operator ==(Object other) bool
The equality operator.
override

Constants

fromJsonFactory → const WidgetLanguagePreset Function(Map<String, dynamic> json)
toJsonFactory → const Map<String, dynamic> Function(WidgetLanguagePreset instance)