WidgetLanguagePresetResponse class

Available extensions
Annotations
  • @JsonSerializable.new(explicitToJson: true)

Constructors

WidgetLanguagePresetResponse({dynamic firstMessage, dynamic textContents})
const
WidgetLanguagePresetResponse.fromJson(Map<String, dynamic> json)
factory

Properties

firstMessage → dynamic
final
hashCode int
The hash code for this object.
no setteroverride
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
textContents → dynamic
final

Methods

copyWith({dynamic firstMessage, dynamic textContents}) WidgetLanguagePresetResponse

Available on WidgetLanguagePresetResponse, provided by the $WidgetLanguagePresetResponseExtension extension

copyWithWrapped({Wrapped? firstMessage, Wrapped? textContents}) WidgetLanguagePresetResponse

Available on WidgetLanguagePresetResponse, provided by the $WidgetLanguagePresetResponseExtension extension

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() Map<String, dynamic>
toString() String
A string representation of this object.
override

Operators

operator ==(Object other) bool
The equality operator.
override

Constants

fromJsonFactory → const WidgetLanguagePresetResponse Function(Map<String, dynamic> json)
toJsonFactory → const Map<String, dynamic> Function(WidgetLanguagePresetResponse instance)