v1PronunciationDictionariesGet method
Future<Response<GetPronunciationDictionariesMetadataResponseModel> >
v1PronunciationDictionariesGet({})
Get Pronunciation Dictionaries @param cursor Used for fetching next page. Cursor is returned in the response. @param page_size How many pronunciation dictionaries to return at maximum. Can not exceed 100, defaults to 30. @param sort Which field to sort by, one of 'created_at_unix' or 'name'. @param sort_direction Which direction to sort the voices in. 'ascending' or 'descending'. @param xi-api-key Your API key. This is required by most endpoints to access our API programatically. You can view your xi-api-key using the 'Profile' tab on the website.
Implementation
Future<chopper.Response<GetPronunciationDictionariesMetadataResponseModel>>
v1PronunciationDictionariesGet({
String? cursor,
int? pageSize,
String? sort,
String? sortDirection,
String? xiApiKey,
}) {
generatedMapping.putIfAbsent(
GetPronunciationDictionariesMetadataResponseModel,
() => GetPronunciationDictionariesMetadataResponseModel.fromJsonFactory,
);
return _v1PronunciationDictionariesGet(
cursor: cursor,
pageSize: pageSize,
sort: sort,
sortDirection: sortDirection,
xiApiKey: xiApiKey?.toString(),
);
}