ClientEvent enum
Values
- swaggerGeneratedUnknown → const ClientEvent
-
const ClientEvent(null) - conversationInitiationMetadata → const ClientEvent
-
const ClientEvent('conversation_initiation_metadata') - asrInitiationMetadata → const ClientEvent
-
const ClientEvent('asr_initiation_metadata') - ping → const ClientEvent
-
const ClientEvent('ping') - audio → const ClientEvent
-
const ClientEvent('audio') - interruption → const ClientEvent
-
const ClientEvent('interruption') - userTranscript → const ClientEvent
-
const ClientEvent('user_transcript') - agentResponse → const ClientEvent
-
const ClientEvent('agent_response') - agentResponseCorrection → const ClientEvent
-
const ClientEvent('agent_response_correction') - clientToolCall → const ClientEvent
-
const ClientEvent('client_tool_call') - vadScore → const ClientEvent
-
const ClientEvent('vad_score') - internalTurnProbability → const ClientEvent
-
const ClientEvent('internal_turn_probability') - internalTentativeAgentResponse → const ClientEvent
-
const ClientEvent('internal_tentative_agent_response') - internalNativeMcpToolCall → const ClientEvent
-
const ClientEvent('internal_native_mcp_tool_call')
Properties
- hashCode → int
-
The hash code for this object.
no setterinherited
- index → int
-
A numeric identifier for the enumerated value.
no setterinherited
- name → String
-
Available on Enum, provided by the EnumName extension
The name of the enum value.no setter - runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- value → String?
-
final
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited
Constants
-
values
→ const List<
ClientEvent> - A constant List of the values in this enum, in order of their declaration.