SafetyRule enum
Values
- swaggerGeneratedUnknown → const SafetyRule
-
const SafetyRule(null) - sexualMinors → const SafetyRule
-
const SafetyRule('sexual_minors') - forgetModeration → const SafetyRule
-
const SafetyRule('forget_moderation') - extremism → const SafetyRule
-
const SafetyRule('extremism') - scamFraud → const SafetyRule
-
const SafetyRule('scam_fraud') - political → const SafetyRule
-
const SafetyRule('political') - selfHarm → const SafetyRule
-
const SafetyRule('self_harm') - illegalDistributionMedical → const SafetyRule
-
const SafetyRule('illegal_distribution_medical') - sexualAdults → const SafetyRule
-
const SafetyRule('sexual_adults') - unknown → const SafetyRule
-
const SafetyRule('unknown')
Properties
- hashCode → int
-
The hash code for this object.
no setterinherited
- index → int
-
A numeric identifier for the enumerated value.
no setterinherited
- name → String
-
Available on Enum, provided by the EnumName extension
The name of the enum value.no setter - runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- value → String?
-
final
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited
Constants
-
values
→ const List<
SafetyRule> - A constant List of the values in this enum, in order of their declaration.