BodyUpdatePVCVoiceSampleV1VoicesPvcVoiceIdSamplesSampleIdPost class
- Available extensions
- Annotations
-
- @JsonSerializable.new(explicitToJson: true)
Constructors
- BodyUpdatePVCVoiceSampleV1VoicesPvcVoiceIdSamplesSampleIdPost({bool? removeBackgroundNoise, dynamic selectedSpeakerIds, dynamic trimStartTime, dynamic trimEndTime})
-
const
-
BodyUpdatePVCVoiceSampleV1VoicesPvcVoiceIdSamplesSampleIdPost.fromJson(Map<
String, dynamic> json) -
factory
Properties
- hashCode → int
-
The hash code for this object.
no setteroverride
- removeBackgroundNoise → bool?
-
final
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- selectedSpeakerIds → dynamic
-
final
- trimEndTime → dynamic
-
final
- trimStartTime → dynamic
-
final
Methods
-
copyWith(
{bool? removeBackgroundNoise, dynamic selectedSpeakerIds, dynamic trimStartTime, dynamic trimEndTime}) → BodyUpdatePVCVoiceSampleV1VoicesPvcVoiceIdSamplesSampleIdPost -
Available on BodyUpdatePVCVoiceSampleV1VoicesPvcVoiceIdSamplesSampleIdPost, provided by the $BodyUpdatePVCVoiceSampleV1VoicesPvcVoiceIdSamplesSampleIdPostExtension extension
-
copyWithWrapped(
{Wrapped< bool?> ? removeBackgroundNoise, Wrapped? selectedSpeakerIds, Wrapped? trimStartTime, Wrapped? trimEndTime}) → BodyUpdatePVCVoiceSampleV1VoicesPvcVoiceIdSamplesSampleIdPost -
Available on BodyUpdatePVCVoiceSampleV1VoicesPvcVoiceIdSamplesSampleIdPost, provided by the $BodyUpdatePVCVoiceSampleV1VoicesPvcVoiceIdSamplesSampleIdPostExtension extension
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toJson(
) → Map< String, dynamic> -
toString(
) → String -
A string representation of this object.
override
Operators
-
operator ==(
Object other) → bool -
The equality operator.
override
Constants
-
fromJsonFactory
→ const BodyUpdatePVCVoiceSampleV1VoicesPvcVoiceIdSamplesSampleIdPost Function(Map<
String, dynamic> json) -
toJsonFactory
→ const Map<
String, dynamic> Function(BodyUpdatePVCVoiceSampleV1VoicesPvcVoiceIdSamplesSampleIdPost instance)