ConversationChargingCommonModel class
- Available extensions
- Annotations
-
- @JsonSerializable.new(explicitToJson: true)
Constructors
- ConversationChargingCommonModel({bool? devDiscount, dynamic tier, LLMCategoryUsage? llmUsage, dynamic llmPrice})
-
const
-
ConversationChargingCommonModel.fromJson(Map<
String, dynamic> json) -
factory
Properties
- devDiscount → bool?
-
final
- hashCode → int
-
The hash code for this object.
no setteroverride
- llmPrice → dynamic
-
final
- llmUsage → LLMCategoryUsage?
-
final
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- tier → dynamic
-
final
Methods
-
copyWith(
{bool? devDiscount, dynamic tier, LLMCategoryUsage? llmUsage, dynamic llmPrice}) → ConversationChargingCommonModel -
Available on ConversationChargingCommonModel, provided by the $ConversationChargingCommonModelExtension extension
-
copyWithWrapped(
{Wrapped< bool?> ? devDiscount, Wrapped? tier, Wrapped<LLMCategoryUsage?> ? llmUsage, Wrapped? llmPrice}) → ConversationChargingCommonModel -
Available on ConversationChargingCommonModel, provided by the $ConversationChargingCommonModelExtension extension
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toJson(
) → Map< String, dynamic> -
toString(
) → String -
A string representation of this object.
override
Operators
-
operator ==(
Object other) → bool -
The equality operator.
override
Constants
-
fromJsonFactory
→ const ConversationChargingCommonModel Function(Map<
String, dynamic> json) -
toJsonFactory
→ const Map<
String, dynamic> Function(ConversationChargingCommonModel instance)