DubbingMetadataResponse class
- Available extensions
- Annotations
-
- @JsonSerializable.new(explicitToJson: true)
Constructors
-
DubbingMetadataResponse({required String dubbingId, required String name, required String status, required List<
String> targetLanguages, dynamic mediaMetadata, dynamic error}) -
const
-
DubbingMetadataResponse.fromJson(Map<
String, dynamic> json) -
factory
Properties
- dubbingId → String
-
final
- error → dynamic
-
final
- hashCode → int
-
The hash code for this object.
no setteroverride
- mediaMetadata → dynamic
-
final
- name → String
-
final
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- status → String
-
final
-
targetLanguages
→ List<
String> -
final
Methods
-
copyWith(
{String? dubbingId, String? name, String? status, List< String> ? targetLanguages, dynamic mediaMetadata, dynamic error}) → DubbingMetadataResponse -
Available on DubbingMetadataResponse, provided by the $DubbingMetadataResponseExtension extension
-
copyWithWrapped(
{Wrapped< String> ? dubbingId, Wrapped<String> ? name, Wrapped<String> ? status, Wrapped<List< ? targetLanguages, Wrapped? mediaMetadata, Wrapped? error}) → DubbingMetadataResponseString> > -
Available on DubbingMetadataResponse, provided by the $DubbingMetadataResponseExtension extension
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toJson(
) → Map< String, dynamic> -
toString(
) → String -
A string representation of this object.
override
Operators
-
operator ==(
Object other) → bool -
The equality operator.
override
Constants
-
fromJsonFactory
→ const DubbingMetadataResponse Function(Map<
String, dynamic> json) -
toJsonFactory
→ const Map<
String, dynamic> Function(DubbingMetadataResponse instance)