GetPronunciationDictionariesMetadataResponseModel class
- Available extensions
- Annotations
-
- @JsonSerializable.new(explicitToJson: true)
Constructors
-
GetPronunciationDictionariesMetadataResponseModel({required List<
GetPronunciationDictionaryMetadataResponseModel> pronunciationDictionaries, dynamic nextCursor, required bool hasMore}) -
const
-
GetPronunciationDictionariesMetadataResponseModel.fromJson(Map<
String, dynamic> json) -
factory
Properties
- hashCode → int
-
The hash code for this object.
no setteroverride
- hasMore → bool
-
final
- nextCursor → dynamic
-
final
-
pronunciationDictionaries
→ List<
GetPronunciationDictionaryMetadataResponseModel> -
final
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
copyWith(
{List< GetPronunciationDictionaryMetadataResponseModel> ? pronunciationDictionaries, dynamic nextCursor, bool? hasMore}) → GetPronunciationDictionariesMetadataResponseModel -
Available on GetPronunciationDictionariesMetadataResponseModel, provided by the $GetPronunciationDictionariesMetadataResponseModelExtension extension
-
copyWithWrapped(
{Wrapped< List< ? pronunciationDictionaries, Wrapped? nextCursor, Wrapped<GetPronunciationDictionaryMetadataResponseModel> >bool> ? hasMore}) → GetPronunciationDictionariesMetadataResponseModel -
Available on GetPronunciationDictionariesMetadataResponseModel, provided by the $GetPronunciationDictionariesMetadataResponseModelExtension extension
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toJson(
) → Map< String, dynamic> -
toString(
) → String -
A string representation of this object.
override
Operators
-
operator ==(
Object other) → bool -
The equality operator.
override
Constants
-
fromJsonFactory
→ const GetPronunciationDictionariesMetadataResponseModel Function(Map<
String, dynamic> json) -
toJsonFactory
→ const Map<
String, dynamic> Function(GetPronunciationDictionariesMetadataResponseModel instance)