QueryParamsJsonSchema class
- Available extensions
- Annotations
-
- @JsonSerializable.new(explicitToJson: true)
Constructors
-
QueryParamsJsonSchema({required Map<
String, dynamic> properties, List<String> ? required}) -
const
-
QueryParamsJsonSchema.fromJson(Map<
String, dynamic> json) -
factory
Properties
- hashCode → int
-
The hash code for this object.
no setteroverride
-
properties
→ Map<
String, dynamic> -
final
-
required
→ List<
String> ? -
final
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
copyWith(
{Map< String, dynamic> ? properties, List<String> ? required}) → QueryParamsJsonSchema -
Available on QueryParamsJsonSchema, provided by the $QueryParamsJsonSchemaExtension extension
-
copyWithWrapped(
{Wrapped< Map< ? properties, Wrapped<String, dynamic> >List< ? required}) → QueryParamsJsonSchemaString> ?> -
Available on QueryParamsJsonSchema, provided by the $QueryParamsJsonSchemaExtension extension
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toJson(
) → Map< String, dynamic> -
toString(
) → String -
A string representation of this object.
override
Operators
-
operator ==(
Object other) → bool -
The equality operator.
override
Constants
-
fromJsonFactory
→ const QueryParamsJsonSchema Function(Map<
String, dynamic> json) -
toJsonFactory
→ const Map<
String, dynamic> Function(QueryParamsJsonSchema instance)