SIPTrunkOutboundCallResponse class
- Available extensions
- Annotations
-
- @JsonSerializable.new(explicitToJson: true)
Constructors
- SIPTrunkOutboundCallResponse({required bool success, required String message, required dynamic conversationId, required dynamic sipCallId})
-
const
-
SIPTrunkOutboundCallResponse.fromJson(Map<
String, dynamic> json) -
factory
Properties
- conversationId → dynamic
-
final
- hashCode → int
-
The hash code for this object.
no setteroverride
- message → String
-
final
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- sipCallId → dynamic
-
final
- success → bool
-
final
Methods
-
copyWith(
{bool? success, String? message, dynamic conversationId, dynamic sipCallId}) → SIPTrunkOutboundCallResponse -
Available on SIPTrunkOutboundCallResponse, provided by the $SIPTrunkOutboundCallResponseExtension extension
-
copyWithWrapped(
{Wrapped< bool> ? success, Wrapped<String> ? message, Wrapped? conversationId, Wrapped? sipCallId}) → SIPTrunkOutboundCallResponse -
Available on SIPTrunkOutboundCallResponse, provided by the $SIPTrunkOutboundCallResponseExtension extension
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toJson(
) → Map< String, dynamic> -
toString(
) → String -
A string representation of this object.
override
Operators
-
operator ==(
Object other) → bool -
The equality operator.
override
Constants
-
fromJsonFactory
→ const SIPTrunkOutboundCallResponse Function(Map<
String, dynamic> json) -
toJsonFactory
→ const Map<
String, dynamic> Function(SIPTrunkOutboundCallResponse instance)