v1ConvaiAgentsAgentIdKnowledgeBaseDocumentationIdGet method
Get Documentation From Knowledge Base @param documentation_id The id of a document from the knowledge base. This is returned on document addition. @param xi-api-key Your API key. This is required by most endpoints to access our API programatically. You can view your xi-api-key using the 'Profile' tab on the website.
Implementation
@deprecated
Future<chopper.Response>
v1ConvaiAgentsAgentIdKnowledgeBaseDocumentationIdGet({
required String? documentationId,
String? xiApiKey,
}) {
return _v1ConvaiAgentsAgentIdKnowledgeBaseDocumentationIdGet(
documentationId: documentationId,
xiApiKey: xiApiKey?.toString(),
);
}