v1ConvaiKnowledgeBaseDocumentationIdRagIndexPost method
Future<Response<RAGIndexResponseModel> >
v1ConvaiKnowledgeBaseDocumentationIdRagIndexPost({
- required String? documentationId,
- String? xiApiKey,
- required RAGIndexRequestModel? body,
Compute Rag Index. @param documentation_id The id of a document from the knowledge base. This is returned on document addition. @param xi-api-key Your API key. This is required by most endpoints to access our API programatically. You can view your xi-api-key using the 'Profile' tab on the website.
Implementation
Future<chopper.Response<RAGIndexResponseModel>>
v1ConvaiKnowledgeBaseDocumentationIdRagIndexPost({
required String? documentationId,
String? xiApiKey,
required RAGIndexRequestModel? body,
}) {
generatedMapping.putIfAbsent(
RAGIndexResponseModel,
() => RAGIndexResponseModel.fromJsonFactory,
);
return _v1ConvaiKnowledgeBaseDocumentationIdRagIndexPost(
documentationId: documentationId,
xiApiKey: xiApiKey?.toString(),
body: body,
);
}