v1ConvaiKnowledgeBaseGet method
Get Knowledge Base List @param cursor Used for fetching next page. Cursor is returned in the response. @param page_size How many documents to return at maximum. Can not exceed 100, defaults to 30. @param search If specified, the endpoint returns only such knowledge base documents whose names start with this string. @param show_only_owned_documents If set to true, the endpoint will return only documents owned by you (and not shared from somebody else). @param types If present, the endpoint will return only documents of the given types. @param use_typesense If set to true, the endpoint will use typesense DB to search for the documents). @param xi-api-key Your API key. This is required by most endpoints to access our API programatically. You can view your xi-api-key using the 'Profile' tab on the website.
Implementation
Future<chopper.Response<GetKnowledgeBaseListResponseModel>>
v1ConvaiKnowledgeBaseGet({
String? cursor,
int? pageSize,
String? search,
bool? showOnlyOwnedDocuments,
List? types,
bool? useTypesense,
String? xiApiKey,
}) {
generatedMapping.putIfAbsent(
GetKnowledgeBaseListResponseModel,
() => GetKnowledgeBaseListResponseModel.fromJsonFactory,
);
return _v1ConvaiKnowledgeBaseGet(
cursor: cursor,
pageSize: pageSize,
search: search,
showOnlyOwnedDocuments: showOnlyOwnedDocuments,
types: types,
useTypesense: useTypesense,
xiApiKey: xiApiKey?.toString(),
);
}