v1DubbingDubbingIdTranscriptLanguageCodeGet method
Future<Response<String> >
v1DubbingDubbingIdTranscriptLanguageCodeGet({
- required String? dubbingId,
- required String? languageCode,
- V1DubbingDubbingIdTranscriptLanguageCodeGetFormatType? formatType,
- String? xiApiKey,
Get Dubbed Transcript @param dubbing_id ID of the dubbing project. @param language_code ID of the language. @param format_type Format to use for the subtitle file, either 'srt' or 'webvtt' @param xi-api-key Your API key. This is required by most endpoints to access our API programatically. You can view your xi-api-key using the 'Profile' tab on the website.
Implementation
Future<chopper.Response<String>> v1DubbingDubbingIdTranscriptLanguageCodeGet({
required String? dubbingId,
required String? languageCode,
enums.V1DubbingDubbingIdTranscriptLanguageCodeGetFormatType? formatType,
String? xiApiKey,
}) {
return _v1DubbingDubbingIdTranscriptLanguageCodeGet(
dubbingId: dubbingId,
languageCode: languageCode,
formatType: formatType?.value?.toString(),
xiApiKey: xiApiKey?.toString(),
);
}