v1VoicesGet method
List Voices @param show_legacy If set to true, legacy premade voices will be included in responses from /v1/voices @param xi-api-key Your API key. This is required by most endpoints to access our API programatically. You can view your xi-api-key using the 'Profile' tab on the website.
Implementation
Future<chopper.Response<GetVoicesResponseModel>> v1VoicesGet({
bool? showLegacy,
String? xiApiKey,
}) {
generatedMapping.putIfAbsent(
GetVoicesResponseModel,
() => GetVoicesResponseModel.fromJsonFactory,
);
return _v1VoicesGet(showLegacy: showLegacy, xiApiKey: xiApiKey?.toString());
}